@@ -112,7 +112,7 @@ class Undouble():
         """Initialize undouble with user-defined parameters."""
         if isinstance(ext, str): ext = [ext]
         # Clean readily fitted models to ensure correct results
-        self.clean()
+        self.clean_init()
         if verbose<=0: verbose=60
         # Store user setting in params
         self.params = {'method': method, 'grayscale': grayscale, 'dim': dim, 'ext': ext, 'hash_size': hash_size, 'verbose': verbose}
@@ -207,6 +207,9 @@ class Undouble():
         if self.results['img_hash_bin'] is None:
             logger.warning('Can not group similar images because no features are present. Tip: Use the compute_hash() function first.')
             return None
+        if self.results['pathnames'] is None:
+            logger.warning("Can not group images because results['pathnames']=None. This happen due to the use of 'clean_files' functionality.")
+            return None
 
         # Make sets of images that are similar based on the minimum defined threshold.
         pathnames, indexes, thresholds = [], [], []
@@ -334,7 +337,7 @@ class Undouble():
             else:
                 shutil.move(file, os.path.join(movedir, os.path.split(file)[1]))
 
-    def clean(self, params=True, results=True):
+    def clean_init(self, params=True, results=True):
         """Clean or removing previous results and models to ensure correct working."""
         if hasattr(self, 'results'):
             logger.info('Cleaning previous fitted model results')
@@ -344,6 +347,20 @@ class Undouble():
         # Store results
         # self.results = {'img':None, 'feat':None, 'xycoord':None, 'pathnames':None, 'labels': None}
 
+    def clean_files(self):
+        """Remove the entire temp directory with all its contents."""
+        # Cleaning temp directory
+
+        if os.path.isdir(self.clustimage.params['tempdir']):
+            files_in_tempdir = os.listdir(self.clustimage.params['tempdir'])
+            _, idx = ismember(files_in_tempdir, self.results['filenames'])
+            logger.info('Removing images in temp directory %s', self.clustimage.params['tempdir'])
+            for i in idx:
+                logger.debug('remove: %s', self.results['pathnames'][i])
+                os.remove(self.results['pathnames'][i])
+                self.results['filenames'][i]=None
+                self.results['pathnames'][i]=None
+
     def import_example(self, data='flowers', url=None):
         """Import example dataset from github source.
 
@@ -491,6 +508,8 @@ class Undouble():
 
                 # Restore verbose status
                 # set_logger(verbose=verbose)
+        else:
+            logger.warning('Selection on threshold does not exits yet. You firt need to group images with image-hash <= threshold using the function: model.group(threshold=0)')
 
     def _check_status(self):
         if not hasattr(self, 'results'):
